@@ -61,6 +61,7 @@ setRefClass("RzPlotLayerOptions",
       color2 <- .self$buildComboEntry("color", colors(), width=120)
       shape2 <- .self$buildEntry("shape", class="any", width=120)
       size2  <- .self$buildEntry("size", class="numeric", width=120)
+      width2 <- .self$buildEntry("width", class="numeric", width=120)
       line2  <- .self$buildCombo("linetype", linetypes, active=1, width=120)
       
       table.option1  <- gtkTableNew(homogeneous=FALSE)
@@ -75,8 +76,10 @@ setRefClass("RzPlotLayerOptions",
       table.option1$attach(shape2[[2]], 1, 2, 2, 3, 5       , "shrink")
       table.option1$attach(size2[[1]] , 0, 1, 3, 4, "shrink", "shrink")
       table.option1$attach(size2[[2]] , 1, 2, 3, 4, 5       , "shrink")
-      table.option1$attach(line2[[1]] , 0, 1, 4, 5, "shrink", "shrink")
-      table.option1$attach(line2[[2]] , 1, 2, 4, 5, 5       , "shrink")
+      table.option1$attach(width2[[1]], 0, 1, 4, 5, "shrink", "shrink")
+      table.option1$attach(width2[[2]], 1, 2, 4, 5, 5       , "shrink")
+      table.option1$attach(line2[[1]] , 0, 1, 5, 6, "shrink", "shrink")
+      table.option1$attach(line2[[2]] , 1, 2, 5, 6, 5       , "shrink")
       
       frame.option1 <- gtkFrameNew("Appearance Options")
       frame.option1$setShadowType(GtkShadowType["etched-in"])
